@@ -7,7 +7,7 @@ use Scalar::Util qw(blessed);
 
 # ABSTRACT: Fancy naming schema of HTTP headers
 
-our $VERSION = '1.000';    # VERSION
+our $VERSION = '1.001';    # VERSION
 
 our @EXPORT_OK = qw(
   decode_key
@@ -92,6 +92,14 @@ sub encode_hash {
     wantarray ? %headers : \%headers;
 }
 
+sub prettify_key {
+    my ( $self, $k ) = _self(@_);
+    $k = lc $k;
+    $k =~ s{-+}{-}g;
+    $k =~ s{(-)(.)}{$1.ucfirst($2)}eg;
+    return ucfirst $k;
+}
+
 sub split_field_hash {
     my ( $self, $value, @rest ) = _self(@_);
     return () unless defined $value;
@@ -250,14 +258,14 @@ HTTP::Headers::Fancy - Fancy naming schema of HTTP headers
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
     my %fancy = decode_hash('content-type' => ..., 'x-foo-bar-baf-baz' => ...);
     my $content_type = $fancy{ContentType};
     my $x_foo_bar_baf_baz = $fancy{-FooBarBafBaz};
-    
+
     my %headers = encode_hash(ContentType => ..., -foo_bar => ...);
     # %headers = ('content-type' => ..., 'x-foo-bar' => ...);
 
@@ -328,21 +336,21 @@ Decode original HTTP header name
 
 The header field name will be separated by the dash ('-') sign into pieces. Every piece will be lowercased and the first character uppercased. The pieces will be concatenated.
 
-    # Original -> Fancy
-    # Accept   Accept
-    # accept   Accept
-    # aCCEPT   Accept
-    # Acc-Ept  AccEpt
-    # Content-Type ContentType
-    # a-b-c    ABC
-    # abc      Abc
-    # a-bc     ABc
-    # ab-c     AbC
+    # Original  ->  Fancy
+    # Accept        Accept
+    # accept        Accept
+    # aCCEPT        Accept
+    # Acc-Ept       AccEpt
+    # Content-Type  ContentType
+    # a-b-c         ABC
+    # abc           Abc
+    # a-bc          ABc
+    # ab-c          AbC
 
 Experimental headers starting with C<X-> will be accessable by a preleading dash sign:
 
-    # Original -> Fancy
-    # x-abc    -Abc
+    # Original  ->  Fancy
+    # x-abc         -Abc
 
 =head2 decode_hash
 
@@ -378,6 +386,21 @@ Removes also a keypair if a value in undefined.
     my %new_hash = encode_hash(%old_hash);
     my $new_hashref = encode_hash($old_hashref);
 
+=head2 prettify_key
+
+Reformats a key with all lowercase and each part uppercase first.
+
+    my $pretty_key = prettify_key('foo-bar');
+
+Examples:
+
+    # Unpretty  ->  Pretty
+    # foo-bar       Foo-Bar
+    # x-fooof       X-Fooof
+    # ABC-DEF       Abc-Def
+
+Since a HTTP header parser ignores the case, this is just for a nice human-readable output.
+
 =head2 split_field_hash
 
 Split a HTTP header field into a hash with decoding of keys
